/*#popoverTable, th , td{*/
/*    width: 100%;*/
/*    border: 1px solid;*/
/*}*/

.left {
    /*float: left;*/
}

.right {
    float: right
}

.right-container {
    position: fixed;
    display: grid;
    right: 0;
    transform: translateY(-50%);
    top: 50%;
}

.popover {
    max-width: 550px;
    max-height: 100%;
    overflow: auto;
}

.popover-header a {
    color: unset
}

#highlighter {
    width: 12rem;
}

.placeholder {
    opacity: unset;
    background-color: unset;
}

/* imitate bootstrap container shrinking */
@media (min-width: 576px) {
    .right-container {
        max-width: 540px;
    }
}

@media (min-width: 768px) {
    .right-container {
        max-width: 720px;
    }
}

@media (min-width: 992px) {
    .right-container {
        max-width: 960px;
    }
}


@media (min-width: 1200px) {
    .right-container {
        max-width: 1140px;
    }
}

@media (min-width: 1400px) {
    .right-container {
        max-width: 1320px;
    }
}
