<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <title>Traits overview (Scoary 2)</title>
    <link rel="icon" type="image/x-icon" href="app/favicon.ico">

    <script src="https://cdnjs.cloudflare.com/ajax/libs/PapaParse/5.3.2/papaparse.min.js"
            crossorigin="anonymous"></script>

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet"
          integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" crossorigin="anonymous">

    <link href="app/overview.css" rel="stylesheet">

    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.10.2/dist/umd/popper.min.js"
            crossorigin="anonymous"></script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"
            integrity="sha384-ka7Sk0Gln4gmtz2MlQnikT1wXgYsOg+OMhuP+IlRH9sENBO0LRn5q+8nbTov4+1p"
            crossorigin="anonymous"></script>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/slim-select/1.27.1/slimselect.min.js"></script>

    <link href="https://cdnjs.cloudflare.com/ajax/libs/slim-select/1.27.1/slimselect.min.css" rel="stylesheet">
</head>

<body>

<section class="container">

    <h1>Traits dendrogram</h1>

    <div class="right-container">
        <object type="image/svg+xml" data="overview_colorbar.svg" id="traits-colorbar" class="right"></object>

        <select id="slim-select"></select>
        <button id="copy-button" type="button" class="btn btn-info">Copy selected traits</button>
        <button id="deselect-button" type="button" class="btn btn btn-warning">Deselect all</button>
    </div>


    <div id="svg-container">
        <!-- <object type="image/svg+xml" data="overview_plot.svg" id="traits-dendrogram" class="left"></object> -->
    </div>

</section>

</body>

<script src="app/overview.js"></script>

</html>
